import React, { useState, useCallback } from 'react'
import { registerSchema, RegisterFormData, FieldErrors } from '../validation'
import { ZodError } from 'zod'

interface UseRegisterFormProps {
    onSubmitSuccess?: (data: RegisterFormData) => void // Optional callback for successful submission
}

export function useRegisterForm({
    onSubmitSuccess,
}: UseRegisterFormProps = {}) {
    const [formData, setFormData] = useState<RegisterFormData>({
        username: '',
        email: '',
        password: '',
        passwordRepeat: '',
        promocode: '',
    })
    const [errors, setErrors] = useState<FieldErrors<RegisterFormData>>({})
    const [isLoading, setIsLoading] = useState(false)
    const [submitError, setSubmitError] = useState<string | null>(null) // For general API errors

    const handleChange = useCallback(
        (e: React.ChangeEvent<HTMLInputElement>) => {
            const { name, value } = e.target
            setFormData(prev => ({ ...prev, [name]: value }))
            // Clear error for the field being edited
            if (errors[name as keyof RegisterFormData]) {
                setErrors(prev => ({ ...prev, [name]: undefined }))
            }
            // Clear general submission error when user starts typing again
            if (submitError) {
                setSubmitError(null)
            }
        },
        [errors, submitError],
    )

    const validateForm = useCallback(() => {
        try {
            registerSchema.parse(formData)
            setErrors({}) // Clear errors if validation passes
            return true
        } catch (error) {
            if (error instanceof ZodError) {
                const fieldErrors: FieldErrors<RegisterFormData> = {}
                error.errors.forEach(err => {
                    if (err.path.length > 0) {
                        fieldErrors[err.path[0] as keyof RegisterFormData] =
                            err.message
                    }
                })
                setErrors(fieldErrors)
            } else {
                console.error(
                    'An unexpected error occurred during validation:',
                    error,
                )
                setSubmitError('An unexpected validation error occurred.') // Generic error for non-Zod issues
            }
            return false
        }
    }, [formData])

    const handleSubmit = useCallback(
        async (e: React.FormEvent<HTMLFormElement>) => {
            e.preventDefault()
            setSubmitError(null) // Clear previous submit errors

            if (!validateForm()) {
                return // Stop submission if validation fails
            }

            setIsLoading(true)
            console.log('Submitting registration data:', formData)

            // --- TODO: Replace with actual API call to your RageMP server ---
            try {
                // Example: Simulate API call
                await new Promise(resolve => setTimeout(resolve, 1500))

                // Assuming API returns success:
                console.log('Registration successful!')
                setFormData({
                    username: '',
                    email: '',
                    password: '',
                    passwordRepeat: '',
                    promocode: '',
                }) // Reset form
                setErrors({})
                if (onSubmitSuccess) {
                    onSubmitSuccess(formData) // Call success callback if provided
                }

                // --- Mock Error Handling (remove in real implementation) ---
                // if (formData.email.includes('fail')) {
                //     throw new Error("Registration failed: Email already exists.");
                // }
                // --- End Mock Error Handling ---
            } catch (apiError: unknown) {
                console.error('Registration API error:', apiError)
                // Try to set a user-friendly error message
                setSubmitError('Registration failed. Please try again.')
            } finally {
                setIsLoading(false)
            }
            // --- End API call section ---
        },
        [formData, validateForm, onSubmitSuccess],
    )

    return {
        formData,
        errors,
        isLoading,
        submitError,
        handleChange,
        handleSubmit,
    }
}
